@@ -15,7 +15,7 @@ $parser->YYData->{verbose_error} = 1;		# 0, 1
 $parser->YYData->{verbose_warning} = 1;		# 0, 1
 $parser->YYData->{verbose_info} = 1;		# 0, 1
 $parser->YYData->{verbose_deprecated} = 1;	# 0, 1 (concerns only version '2.4' and upper)
-$parser->YYData->{symbtab} = new Symbtab($parser);
+$parser->YYData->{symbtab} = new CORBA::IDL::Symbtab($parser);
 my $cflags = '-D__idl2c';
 if ($Parser::IDL_version lt '3.0') {
 	$cflags .= ' -D_PRE_3_0_COMPILER_';
@@ -27,7 +27,19 @@ if ($^O eq 'MSWin32') {
 } else {
 	$parser->YYData->{preprocessor} = 'cpp -C ' . $cflags;
 }
-$parser->getopts("i:x");
+$parser->getopts("hi:vx");
+if ($parser->YYData->{opt_v}) {
+	print "CORBA::C $CORBA::C::VERSION\n";
+	print "CORBA::IDL $CORBA::IDL::VERSION\n";
+	print "IDL $Parser::IDL_version\n";
+	print "$0\n";
+	print "Perl $]\n";
+	exit;
+}
+if ($parser->YYData->{opt_h}) {
+	use Pod::Usage;
+	pod2usage(-verbose => 1);
+}
 $parser->Run(@ARGV);
 $parser->YYData->{symbtab}->CheckForward();
 $parser->YYData->{symbtab}->CheckRepositoryID();
@@ -54,16 +66,16 @@ if (        $parser->YYData->{verbose_deprecated}
 
 if (        exists $parser->YYData->{root}
 		and ! exists $parser->YYData->{nb_error} ) {
-	$parser->YYData->{root}->visitName(new repositoryIdVisitor($parser));
+	$parser->YYData->{root}->visit(new CORBA::IDL::repositoryIdVisitor($parser));
 	if (        $Parser::IDL_version ge '3.0'
 			and $parser->YYData->{opt_x} ) {
 		$parser->YYData->{symbtab}->Export();
 	}
-	$parser->YYData->{root}->visitName(new CnameVisitor($parser));
-	$parser->YYData->{root}->visitName(new CliteralVisitor($parser));
-	$parser->YYData->{root}->visitName(new ClengthVisitor($parser));
-	$parser->YYData->{root}->visitName(new CtypeVisitor($parser));
-	$parser->YYData->{root}->visit(new CincludeVisitor($parser));
+	$parser->YYData->{root}->visit(new CORBA::C::nameVisitor($parser));
+	$parser->YYData->{root}->visit(new CORBA::C::literalVisitor($parser));
+	$parser->YYData->{root}->visit(new CORBA::C::lengthVisitor($parser));
+	$parser->YYData->{root}->visit(new CORBA::C::typeVisitor($parser));
+	$parser->YYData->{root}->visit(new CORBA::C::includeVisitor($parser));
 }
 
 __END__
@@ -72,13 +84,13 @@ __END__
 
 idl2c - IDL compiler to language C mapping
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
 idl2c [options] I<spec>.idl
 
 =head1 OPTIONS
 
-All options are forwarded to C preprocessor, except -i -x.
+All options are forwarded to C preprocessor, except -h -i -v -x.
 
 With the GNU C Compatible Compiler Processor, useful options are :
 
@@ -100,13 +112,21 @@ Specific options :
 
 =over 8
 
+=item B<-h>
+
+Display help.
+
 =item B<-i> I<directory>
 
-Specify a path for import (only for version 3.0).
+Specify a path for import (only for IDL version 3.0).
+
+=item B<-v>
+
+Display version.
 
 =item B<-x>
 
-Enable export (only for version 3.0).
+Enable export (only for IDL version 3.0).
 
 =back
 
@@ -118,8 +138,6 @@ a include file following the language C mapping rules.
 B<idl2c> is a Perl OO application what uses the visitor design pattern.
 The parser is generated by Parse::Yapp.
 
-B<idl2c> needs Math::BigInt and Math::BigFloat modules.
-
 B<idl2c> needs a B<cpp> executable.
 
 CORBA Specifications, including IDL (Interface Language Definition) and
@@ -131,9 +149,9 @@ cpp, perl
 
 =head1 COPYRIGHT
 
-(c) 2001-2003 Francois PERRAD, France. All rights reserved.
+(c) 2001-2004 Francois PERRAD, France. All rights reserved.
 
-This program and all CORBA::IDL modules are distributed
+This program and all CORBA::C modules are distributed
 under the terms of the Artistic Licence.
 
 =head1 AUTHOR
